package Kephra::Module::Demo;
use strict;
use warnings;

our $VERSION = '0.01';

#################################################
# Demoplugin as an tutorial for plugin authors
#################################################


sub start{
}

1;
